@@ -1,4 +1,4 @@
-from .build import build_package
+from .run import build_package
 
 if __name__ == "__main__":
     build_package()
